<?php
/**
 * The template for displaying product content in the single-product.php template
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce\Templates
 * @version 3.6.0
 */

defined( 'ABSPATH' ) || exit;

global $product;

/**
 * Hook: woocommerce_before_single_product.
 *
 * @hooked woocommerce_output_all_notices - 10
 */
do_action( 'woocommerce_before_single_product' );

if ( post_password_required() ) {
	echo get_the_password_form(); // WPCS: XSS ok.
	return;
}

$classes		= pls_woocommerce_product_class();
$product_layout = pls_get_product_gallery_style();
$content_layout = pls_get_post_meta( 'single_product_content_layout' );

if( ! $content_layout || 'default' == $content_layout ) {
	$content_layout = pls_get_option( 'single-product-content-layout', 'style-1' );
}

if ( 'product-gallery-horizontal' == $product_layout ){
	$content_layout = 'style-4';
}
$classes[]	= pls_get_option( 'sticky-product-image', 1 ) ? 'has-product-gallery-sticky' : '';
$classes[]	= pls_get_option( 'sticky-product-summary', 1 ) ? 'has-product-summary-sticky' : ''; ?>

<div id="product-<?php the_ID(); ?>" <?php wc_product_class( $classes, $product ); ?>>
	
	<?php wc_get_template_part( 'single-product-content', $content_layout ); ?>
	
	<?php
		/**
		 * Hook: woocommerce_after_single_product_summary.
		 *
		 * @hooked woocommerce_output_product_data_tabs - 10
		 * @hooked woocommerce_upsell_display - 15
		 * @hooked woocommerce_output_related_products - 20
		 */
		do_action( 'woocommerce_after_single_product_summary' );
	?>
</div>

<?php do_action( 'woocommerce_after_single_product' ); ?>
